==> hs-stringsearch-0.3.6.tbz: lib/ghc-7.0.3/cabal/stringsearch-0.3.6/register.sh <==
#!/bin/sh
echo 'name: stringsearch
version: 0.3.6
id: stringsearch-0.3.6-30193c57fefe9bc518ca9775f8d1858a

license: BSD3
copyright: (c) 2007-2011
           Daniel Fischer, Chris Kuklewicz, Justin Bailey
maintainer: daniel.is.fischer@googlemail.com
stability:
homepage: https://bitbucket.org/dafis/stringsearch
package-url:
description: This package provides several functions to quickly
             search for substrings in strict or lazy ByteStrings.
             It also provides functions for breaking or splitting
             on substrings and replacing all occurrences of a
             substring (the first in case of overlaps) with another.
             GHC before 6.8 are no longer supported, other compilers
             only if they support BangPatterns. If you need it to
             work with other compilers, send a feature request.
category: Text, Search
author: Daniel Fischer, Chris Kuklewicz, Justin Bailey
exposed: True
exposed-modules: Data.ByteString.Search
                 Data.ByteString.Search.BoyerMoore Data.ByteString.Search.DFA
                 Data.ByteString.Search.KarpRabin Data.ByteString.Search.KMP
                 Data.ByteString.Search.KnuthMorrisPratt
                 Data.ByteString.Search.Substitution Data.ByteString.Lazy.Search
                 Data.ByteString.Lazy.Search.DFA
                 Data.ByteString.Lazy.Search.KarpRabin
                 Data.ByteString.Lazy.Search.KMP
hidden-modules: Data.ByteString.Search.Internal.BoyerMoore
                Data.ByteString.Search.Internal.KnuthMorrisPratt
                Data.ByteString.Search.Internal.Utils
                Data.ByteString.Lazy.Search.Internal.BoyerMoore
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/stringsearch-0.3.6
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/stringsearch-0.3.6
              /usr/local/lib
hs-libraries: HSstringsearch-0.3.6
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
         base-4.3.1.0-63fd52d9e7e39016c91be0baf3543757
         bytestring-0.9.1.10-94a0a1c920aee21a485bdf21fd51b2be
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/stringsearch-0.3.6/html/stringsearch.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/stringsearch-0.3.6/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-stringsearch-0.3.6.3.tbz: lib/ghc-7.0.4/cabal/stringsearch-0.3.6.3/register.sh <==
#!/bin/sh
echo 'name: stringsearch
version: 0.3.6.3
id: stringsearch-0.3.6.3-24f6182723c0689dc917d76487478a02

license: BSD3
copyright: (c) 2007-2011
           Daniel Fischer, Chris Kuklewicz, Justin Bailey
maintainer: daniel.is.fischer@googlemail.com
stability:
homepage: https://bitbucket.org/dafis/stringsearch
package-url:
description: This package provides several functions to quickly
             search for substrings in strict or lazy ByteStrings.
             It also provides functions for breaking or splitting
             on substrings and replacing all occurrences of a
             substring (the first in case of overlaps) with another.
             GHC before 6.10 are no longer supported, other compilers
             only if they support BangPatterns. If you need it to
             work with other compilers, send a feature request.
category: Text, Search
author: Daniel Fischer, Chris Kuklewicz, Justin Bailey
exposed: True
exposed-modules: Data.ByteString.Search
                 Data.ByteString.Search.BoyerMoore Data.ByteString.Search.DFA
                 Data.ByteString.Search.KarpRabin Data.ByteString.Search.KMP
                 Data.ByteString.Search.KnuthMorrisPratt
                 Data.ByteString.Search.Substitution Data.ByteString.Lazy.Search
                 Data.ByteString.Lazy.Search.DFA
                 Data.ByteString.Lazy.Search.KarpRabin
                 Data.ByteString.Lazy.Search.KMP
hidden-modules: Data.ByteString.Search.Internal.BoyerMoore
                Data.ByteString.Search.Internal.KnuthMorrisPratt
                Data.ByteString.Search.Internal.Utils
                Data.ByteString.Lazy.Search.Internal.BoyerMoore
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/stringsearch-0.3.6.3
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/stringsearch-0.3.6.3
              /usr/local/lib
hs-libraries: HSstringsearch-0.3.6.3
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
         base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         bytestring-0.9.1.10-94a0a1c920aee21a485bdf21fd51b2be
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/stringsearch-0.3.6.3/html/stringsearch.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/stringsearch-0.3.6.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
